==> mili-3.8.2.tgz: package/es/src/commands/update.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { Project, Resource, Effect, EffectOptions } from "../internal";
import { recursiveExecte, logger, checkWorkDir } from "../utils";
import semver from 'semver';
export default recursiveExecte((options) => __awaiter(void 0, void 0, void 0, function* () {
    const cwd = options.cwd || process.cwd();
    const noDeps = options.noDeps || false;
    const version = options.version;
    const force = options.force || false;
    Effect.replace(options.effect);
    if (!force)
        yield checkWorkDir(cwd);
    const project = yield Project.load(cwd);
    const repo = yield project.getTemplateRepo();
    if (version && repo.version && semver.lt(version, repo.version)) {
        const message = [
            'The version number setted is lower than the current template version.',
            "If you're sure you want to run this command, rerun it with --force.",
        ].join('\n');
        if (force)
            logger.warn(message);
        else
            throw new Error(message);
    }
    if (version)
        yield repo.checkout(version);
    const template = yield repo.install({ noDeps });
    const resource = new Resource('update', project, template);
    const compiler = yield resource.compile();
    yield compiler.render();
    yield compiler.emit('updated');
}));

==> mili-3.9.1.tgz: package/es/src/commands/update.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { Project, Resource, Effect, EffectOptions } from "../internal";
import { recursiveExecte, logger, checkWorkDir } from "../utils";
import semver from 'semver';
export default recursiveExecte((options) => __awaiter(void 0, void 0, void 0, function* () {
    const cwd = options.cwd || process.cwd();
    const noDeps = options.noDeps || false;
    const version = options.version;
    const force = options.force || false;
    Effect.replace(options.effect);
    if (!force)
        yield checkWorkDir(cwd);
    const project = yield Project.load(cwd);
    const repo = yield project.getTemplateRepo();
    if (version && repo.version && version !== 'default' && version !== 'latest' && semver.lt(version, repo.version)) {
        const message = [
            'The version number setted is lower than the current template version.',
            "If you're sure you want to run this command, rerun it with --force.",
        ].join('\n');
        if (force)
            logger.warn(message);
        else
            throw new Error(message);
    }
    if (version)
        yield repo.checkout(version);
    const template = yield repo.install({ noDeps });
    const resource = new Resource('update', project, template);
    const compiler = yield resource.compile();
    yield compiler.render();
    yield compiler.emit('updated');
}));
